#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# opensecurity_service
# 
# turn the opensecurityd into a Windows Service
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2014 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import os
import os.path
import time
import servicemanager
import win32event
import win32service
import win32serviceutil

from opensecurity_util import logger
import opensecurityd


# ------------------------------------------------------------
# code


class OpenSecurityService(win32serviceutil.ServiceFramework):
    
    """This is the OpenSecurity Windows Service,"""

    _svc_name_ = 'OpenSecurityService'
    _svc_display_name_ = 'OpenSecurity Service'
    _svc_description_ = 'OpenSecurity Daemon Service'

    _run = True
    
    def __init__(self, args):

        """Init the Service"""
        
        # super call 
        win32serviceutil.ServiceFramework.__init__(self, args)
        self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)


    def SvcStop(self):
        
        """Stopping the Service"""

        self.log('OpenSecurity Service stopping...\n') 
        self._run = False
        self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
        win32event.SetEvent(self.hWaitStop)
        self.log('OpenSecurity Service stopped...\n') 


    def SvcDoRun(self):
    
        """Run the Service"""

        self.log('OpenSecurity Service stared now')
        servicemanager.LogMsg(servicemanager.EVENTLOG_INFORMATION_TYPE,
                              servicemanager.PYS_SERVICE_STARTED,
                              (self._svc_name_, ''))
        self._run = True
        self.main()


    def log(self, s):

        """log some string to the log file"""

        try:
            logger.debug(s)
        except:
            pass


    def main(self):

        """Main service method"""
        opensecurityd.main()


if __name__ == '__main__':
    """startup"""
    win32serviceutil.HandleCommandLine(OpenSecurityService)

